import { Getter, Provider, Setter } from '@loopback/context';
import { Request } from '@loopback/rest';
import { AuthenticateFn, AuthenticationStrategy, UserProfile } from '../types';
/**
 * Provides the authentication action for a sequence
 * @example `context.bind('authentication.actions.authenticate').toProvider(AuthenticateActionProvider)`
 */
export declare class AuthenticateActionProvider implements Provider<AuthenticateFn> {
    readonly getStrategy: Getter<AuthenticationStrategy>;
    readonly setCurrentUser: Setter<UserProfile>;
    constructor(getStrategy: Getter<AuthenticationStrategy>, setCurrentUser: Setter<UserProfile>);
    /**
     * @returns authenticateFn
     */
    value(): AuthenticateFn;
    /**
     * The implementation of authenticate() sequence action.
     * @param request - The incoming request provided by the REST layer
     */
    action(request: Request): Promise<UserProfile | undefined>;
}
